<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>BoolEdit</name>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Booléen</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">nom</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Valeur:</translation>
    </message>
    <message>
        <source>True</source>
        <translation type="obsolete">Vrai</translation>
    </message>
    <message>
        <source>False</source>
        <translation type="obsolete">Faux</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Activé</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nom:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annuler</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
</context>
<context>
    <name>DoubleEdit</name>
    <message>
        <source>Double</source>
        <translation type="obsolete">Double</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Valeur:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">nom</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Activé</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nom:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt-O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annuler</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
</context>
<context>
    <name>IntEdit</name>
    <message>
        <source>Int</source>
        <translation type="obsolete">Entier</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Valeur:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">nom</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Activé</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nom:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annuler</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
</context>
<context>
    <name>LanguageOptions</name>
    <message>
        <location filename="languageoptions.cpp" line="74"/>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
</context>
<context>
    <name>ListEdit</name>
    <message>
        <source>String</source>
        <translation type="obsolete">Chaîne</translation>
    </message>
    <message>
        <source>Int</source>
        <translation type="obsolete">Entier</translation>
    </message>
    <message>
        <source>Double</source>
        <translation type="obsolete">Double</translation>
    </message>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Booléen</translation>
    </message>
    <message>
        <source>List</source>
        <translation type="obsolete">Liste</translation>
    </message>
    <message>
        <source>Unknown Type</source>
        <translation type="obsolete">Type inconnu</translation>
    </message>
    <message>
        <source>I do not understand the type %1.</source>
        <translation type="obsolete">Je ne comprends pas le type %1.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="obsolete">Avertissement</translation>
    </message>
    <message>
        <source>I do not know how to edit QVariant type %1.</source>
        <translation type="obsolete">Je ne sais pas éditer le type de QVariant %1.</translation>
    </message>
    <message>
        <source>The item you selected is not a QListBoxVariant item. I do not know what to do.</source>
        <translation type="obsolete">L&apos;élément que vous avez sélectionné n&apos;est pas un QListBoxVariant. Je ne sais pas quoi en faire.</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Activé</translation>
    </message>
    <message>
        <source>Values:</source>
        <translation type="obsolete">Valeurs:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nom:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">nom</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annuler</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="obsolete">&amp;Nouveau</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation type="obsolete">&amp;Monter</translation>
    </message>
    <message>
        <source>Alt+U</source>
        <translation type="obsolete">Alt+U</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="obsolete">&amp;Editer</translation>
    </message>
    <message>
        <source>Alt+E</source>
        <translation type="obsolete">Alt+E</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation type="obsolete">&amp;Descendre</translation>
    </message>
    <message>
        <source>Alt+D</source>
        <translation type="obsolete">Alt+D</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Supprimer</translation>
    </message>
</context>
<context>
    <name>NewVariant</name>
    <message>
        <source>New Variant</source>
        <translation type="obsolete">Nouveau type (Variant)</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Type:</translation>
    </message>
    <message>
        <source>String</source>
        <translation type="obsolete">Chaîne</translation>
    </message>
    <message>
        <source>Int</source>
        <translation type="obsolete">Entier</translation>
    </message>
    <message>
        <source>Double</source>
        <translation type="obsolete">Double</translation>
    </message>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Booléen</translation>
    </message>
    <message>
        <source>List</source>
        <translation type="obsolete">Liste</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nom:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annuler</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
</context>
<context>
    <name>ParamListEdit</name>
    <message>
        <location filename="paramlistedit.ui" line="30"/>
        <source>List</source>
        <translation>Liste</translation>
    </message>
    <message>
        <location filename="paramlistedit.ui" line="41"/>
        <source>List:</source>
        <translation>Liste:</translation>
    </message>
    <message>
        <location filename="paramlistedit.ui" line="64"/>
        <source>Select</source>
        <translation>Sélectionner</translation>
    </message>
    <message>
        <location filename="paramlistedit.ui" line="71"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>ParameterEdit</name>
    <message>
        <location filename="parameteredit.ui" line="38"/>
        <source>Active</source>
        <translation>Activé</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="43"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="48"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="53"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="187"/>
        <source>Name already exists</source>
        <translation>Le nom existe déjà</translation>
    </message>
    <message>
        <source>The name for the parameter you specified already exists in the list.</source>
        <translation type="obsolete">Le nom du paramètre spécifié existe déjà dans la liste.</translation>
    </message>
    <message>
        <source>String</source>
        <translation type="obsolete">Chaîne</translation>
    </message>
    <message>
        <source>Int</source>
        <translation type="obsolete">Entier</translation>
    </message>
    <message>
        <source>Double</source>
        <translation type="obsolete">Double</translation>
    </message>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Booléen</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="113"/>
        <source>List</source>
        <translation>Liste</translation>
    </message>
    <message>
        <source>Unknown Type</source>
        <translation type="obsolete">Type inconnu</translation>
    </message>
    <message>
        <source>I do not understand the type %1.</source>
        <translation type="obsolete">Je ne comprends pas le type %1.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="obsolete">Avertissement</translation>
    </message>
    <message>
        <source>I do not know how to edit QVariant type %1.</source>
        <translation type="obsolete">Je ne sais pas éditer le type de QVariant %1.</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="31"/>
        <source>Parameter List</source>
        <translation>Liste de paramètres</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="63"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="66"/>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="73"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="76"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="93"/>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="96"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="103"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editer</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="106"/>
        <location filename="parameteredit.ui" line="116"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="123"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="75"/>
        <source>Not a Valid Report</source>
        <translation>Pas un rapport valide</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="76"/>
        <source>The report definition does not appear to be a valid report.

The root node is not &apos;report&apos;.</source>
        <translation>La définition de rapport parait invalide.

Le noeud racine n&apos;est pas &apos;report&apos;.</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="188"/>
        <source>&lt;p&gt;The name for the parameter you specified already exists in the list.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ParameterProperties</name>
    <message>
        <location filename="parameterproperties.ui" line="14"/>
        <source>Parameter Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="20"/>
        <source>Type:</source>
        <translation type="unfinished">Type:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="34"/>
        <location filename="parameterproperties.cpp" line="107"/>
        <location filename="parameterproperties.cpp" line="207"/>
        <location filename="parameterproperties.cpp" line="274"/>
        <location filename="parameterproperties.cpp" line="301"/>
        <source>String</source>
        <translation type="unfinished">Chaîne</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="39"/>
        <location filename="parameterproperties.cpp" line="95"/>
        <location filename="parameterproperties.cpp" line="198"/>
        <location filename="parameterproperties.cpp" line="280"/>
        <location filename="parameterproperties.cpp" line="307"/>
        <source>Bool</source>
        <translation type="unfinished">Booléen</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="44"/>
        <location filename="parameterproperties.cpp" line="99"/>
        <location filename="parameterproperties.cpp" line="201"/>
        <location filename="parameterproperties.cpp" line="276"/>
        <location filename="parameterproperties.cpp" line="303"/>
        <source>Int</source>
        <translation type="unfinished">Entier</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="49"/>
        <location filename="parameterproperties.cpp" line="103"/>
        <location filename="parameterproperties.cpp" line="204"/>
        <location filename="parameterproperties.cpp" line="278"/>
        <location filename="parameterproperties.cpp" line="305"/>
        <source>Double</source>
        <translation type="unfinished">Double</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="54"/>
        <location filename="parameterproperties.cpp" line="111"/>
        <location filename="parameterproperties.cpp" line="210"/>
        <location filename="parameterproperties.cpp" line="282"/>
        <location filename="parameterproperties.cpp" line="309"/>
        <source>List</source>
        <translation type="unfinished">Liste</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="72"/>
        <source>Name:</source>
        <translation type="unfinished">Nom:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="95"/>
        <location filename="parameterproperties.ui" line="115"/>
        <location filename="parameterproperties.ui" line="155"/>
        <location filename="parameterproperties.ui" line="175"/>
        <source>Value:</source>
        <translation type="unfinished">Valeur:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="135"/>
        <source>False</source>
        <translation type="unfinished">Faux</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="140"/>
        <source>True</source>
        <translation type="unfinished">Vrai</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="192"/>
        <source>Values:</source>
        <translation type="unfinished">Valeurs:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="210"/>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Nouveau</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="213"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="230"/>
        <source>Move &amp;Up</source>
        <translation type="unfinished">&amp;Monter</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="233"/>
        <source>Alt+U</source>
        <translation type="unfinished">Alt+U</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="240"/>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Editer</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="243"/>
        <source>Alt+E</source>
        <translation type="unfinished">Alt+E</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="250"/>
        <source>Move &amp;Down</source>
        <translation type="unfinished">&amp;Descendre</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="253"/>
        <source>Alt+D</source>
        <translation type="unfinished">Alt+D</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="270"/>
        <source>Delete</source>
        <translation type="unfinished">Supprimer</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="299"/>
        <source>Active</source>
        <translation type="unfinished">Activé</translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="115"/>
        <location filename="parameterproperties.cpp" line="188"/>
        <location filename="parameterproperties.cpp" line="213"/>
        <source>Warning</source>
        <translation type="unfinished">Avertissement</translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="116"/>
        <source>I do not know how to edit QVariant type %1.</source>
        <translation type="unfinished">Je ne sais pas éditer le type de QVariant %1.</translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="189"/>
        <location filename="parameterproperties.cpp" line="214"/>
        <source>I do not recognize type %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="285"/>
        <location filename="parameterproperties.cpp" line="312"/>
        <source>Unknown Type</source>
        <translation type="unfinished">Type inconnu</translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="286"/>
        <location filename="parameterproperties.cpp" line="313"/>
        <source>I do not understand the type %1.</source>
        <translation type="unfinished">Je ne comprends pas le type %1.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="data.cpp" line="25"/>
        <source>%1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="data.cpp" line="26"/>
        <source>Copyright (c) 2002-2012, OpenMFG, LLC.</source>
        <oldsource>Copyright (c) 2002-2011, OpenMFG, LLC.</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="data.cpp" line="28"/>
        <source>3.3.4</source>
        <oldsource>3.3.1</oldsource>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StringEdit</name>
    <message>
        <source>String</source>
        <translation type="obsolete">Chaîne</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Valeur:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">nom</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Activé</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nom:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annuler</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
</context>
<context>
    <name>login</name>
    <message>
        <location filename="login.cpp" line="146"/>
        <source>Initializing the Database Connector</source>
        <translation>Initialisation du connecteur à la base</translation>
    </message>
    <message>
        <location filename="login.cpp" line="159"/>
        <source>No Database Driver</source>
        <translation>Pas de pilote de base de données</translation>
    </message>
    <message>
        <location filename="login.cpp" line="160"/>
        <source>A connection could not be established with the specified
Database as the Proper Database Drivers have not been installed.
Contact your Systems Administrator.
</source>
        <translation>
        La connection n&apos;a pas pu être établie avec la base spécifiée
        car les pilotes requis n&apos;ont pas été installés.
        Contactez votre administrateur système.
      </translation>
    </message>
    <message>
        <location filename="login.cpp" line="180"/>
        <source>Connecting to the Database</source>
        <translation>Connexion à la base</translation>
    </message>
    <message>
        <location filename="login.cpp" line="193"/>
        <source>Cannot Connect to Database Server</source>
        <translation>Impossible de se connecter au serveur de base de données</translation>
    </message>
    <message>
        <location filename="login.cpp" line="194"/>
        <source>A connection to the specified Database Server cannot be made.  This may be due to an
incorrect Username and/or Password or that the Database Server in question cannot
support anymore connections.

Please verify your Username and Password and try again or wait until the specified
Database Server is less busy.

System Error &apos;%1&apos;
%2</source>
        <translation>
        La connexion à la base spécifiée est impossible. Ceci peut être dû à un nom d&apos;utilisateur
        ou un mot de passe incorrect ou bien que le serveur en question n&apos;accepte pas de
        connexions supplémentaires.

        Veuillez vérifier votre nom d&apos;utilisateur et mot de passe et réessayer ou attendez que le
        serveur soit moins occupé.

        Erreur système &apos;%1&apos;
        %2
      </translation>
    </message>
    <message>
        <location filename="login.cpp" line="214"/>
        <source>Logging into the Database</source>
        <translation>Connexion à la base</translation>
    </message>
    <message>
        <location filename="login.ui" line="31"/>
        <source>Log In</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <location filename="login.ui" line="2010"/>
        <source>Build: </source>
        <translation>Build: </translation>
    </message>
    <message>
        <location filename="login.ui" line="2538"/>
        <source>&amp;Username:</source>
        <translation>&amp;Utilisateur:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2551"/>
        <source>&amp;Password:</source>
        <translation>&amp;Mot de passe:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2637"/>
        <source>S&amp;erver:</source>
        <translation>&amp;Serveur:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2650"/>
        <source>&amp;Database:</source>
        <translation>&amp;Base de données:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2781"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="login.ui" line="2788"/>
        <source>&amp;Login</source>
        <translation>&amp;Connecter</translation>
    </message>
    <message>
        <location filename="login.ui" line="2801"/>
        <source>&amp;Options</source>
        <translation>&amp;Options</translation>
    </message>
    <message>
        <location filename="login.cpp" line="112"/>
        <source>Version </source>
        <translation>Version </translation>
    </message>
</context>
<context>
    <name>loginOptions</name>
    <message>
        <location filename="loginOptions.ui" line="31"/>
        <source>Login Options</source>
        <translation>Options de connexion</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="87"/>
        <source>&amp;Database:</source>
        <translation>&amp;Base de données:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="194"/>
        <source>S&amp;erver:</source>
        <translation>&amp;Serveur:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="219"/>
        <source>&amp;Port:</source>
        <translation>&amp;Port:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="246"/>
        <source>Driver:</source>
        <translation>Pilote:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="309"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="316"/>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="260"/>
        <source>PostgreSQL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="265"/>
        <source>ODBC</source>
        <translation></translation>
    </message>
</context>
</TS>
